# DF4cats

Easy handling of Machine Learning DataFrames with categorical variables.

Easy cleaning, encoding and decoding and embedding of categorical variables, including handy features for production pipelines.

## Installation

```
pip install df4cats
```
